@@ -8,13 +8,13 @@ client = TestClient(app)
 
 def test_text_get():
     response = client.get("/text")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == "Hello World"
 
 
 def test_nonexistent():
     response = client.get("/nonexistent")
-    assert response.status_code == 404
+    assert response.status_code == 404, response.text
     assert response.json() == {"detail": "Not Found"}
 
 
@@ -193,7 +193,6 @@ response_less_than_equal_3 = {
         ("/path/bool/False", 200, False),
         ("/path/bool/false", 200, False),
         ("/path/param/foo", 200, "foo"),
-        ("/path/param-required/foo", 200, "foo"),
         ("/path/param-minlength/foo", 200, "foo"),
         ("/path/param-minlength/fo", 422, response_at_least_3),
         ("/path/param-maxlength/foo", 200, "foo"),
